Specifications
==============

Links to various specifications relevant to the project:

- [Extensible Markup Language (XML) 1.0 (Fifth Edition)](https://www.w3.org/tr/xml/)
- [Extensible Markup Language (XML) 1.1 (Second Edition)](https://www.w3.org/tr/xml11/)
- [Namespaces in XML 1.0 (Third Edition)](https://www.w3.org/tr/xml-names/)
- [XML Schema Part 0: Primer (Second Edition)](https://www.w3.org/tr/xmlschema-0/)
- [XML Schema Part 1: Structures (Second Edition)](https://www.w3.org/tr/xmlschema-1/)
- [XML Schema Part 2: Datatypes (Second Edition)](https://www.w3.org/tr/xmlschema-2/)
- [Simple Object Access Protocol (SOAP) 1.1](https://www.w3.org/tr/soap11/)
- [Simple Object Access Protocol (SOAP) 1.2 Part 1: Messaging Framework (Second Edition)](https://www.w3.org/tr/soap12-part1/)
- [Simple Object Access Protocol (SOAP) 1.2 Part 2: Adjuncts (Second Edition)](https://www.w3.org/tr/soap12-part2/)
- [Simple Object Access Protocol (SOAP) 1.2 Specific Assertions and Test Collection (Second Edition)](https://www.w3.org/tr/soap12-testcollection/)
- [Web Services Description Language (WSDL) 1.1](https://www.w3.org/tr/wsdl)
- [Web Services Description Language (WSDL) 2.0 Part 0: Primer](https://www.w3.org/tr/wsdl20-primer)
- [Web Services Description Language (WSDL) 2.0 Part 1: Core Language](https://www.w3.org/tr/wsdl20)
- [Web Services Description Language (WSDL) 2.0 Part 2: Adjuncts](https://www.w3.org/tr/wsdl20-adjuncts)
- [Web Services Description Language (WSDL) 2.0 Additional MEPs](https://www.w3.org/tr/wsdl20-additional-meps/)
- [Web Services Addressing 1.0 - Core](https://www.w3.org/tr/ws-addr-core/)
- [Web Services Addressing 1.0 - SOAP Binding](https://www.w3.org/tr/ws-addr-soap/)
- [Web Services Addressing 1.0 - WSDL Binding](https://www.w3.org/tr/ws-addr-wsdl/)
- [Web Services Architecture](https://www.w3.org/tr/ws-arch/)
- [Web Services Security 1.0](https://docs.oasis-open.org/wss/2004/01/oasis-200401-wss-soap-message-security-1.0.pdf)
- [Web Services Security 1.1](https://www.oasis-open.org/committees/download.php/16790/wss-v1.1-spec-os-SOAPMessageSecurity.pdf)

- [WSDL 1.1 Binding Extension for SOAP 1.2](https://www.w3.org/submission/wsdl11soap12/)
